# SCB Payment Python

A Python library for [SCB Payment](https://developer.scb/) API - SCB Python


| Name                                                        | Description               |
| ------------------------------------------------------------|---------------------------|
| [qrcode_payment.md (*Only Sandbox)](qrcode_payment.md)      | QR Code Payment           |
